@@ -21,6 +21,11 @@ def job(tmp_path):
     return touch(tmp_path, "job.yaml")
 
 
+@pytest.fixture
+def run(mocker):
+    return mocker.patch("tuxrun.__main__.run")
+
+
 @pytest.fixture
 def tuxrun_args(monkeypatch, device, job):
     args = ["tuxrun", "--device-dict", str(device), "--definition", str(job)]
@@ -58,10 +63,10 @@ def test_start_calls_main(monkeypatch, mocker):
     main.assert_called()
 
 
-def test_main_usage(capsys):
-    with pytest.raises(SystemExit) as e:
-        main()
-    assert e.value.code != 0
+def test_main_usage(monkeypatch, capsys):
+    monkeypatch.setattr("tuxrun.__main__.sys.argv", ["tuxrun"])
+    ret = main()
+    assert ret != 0
     _, err = capsys.readouterr()
     assert "usage: tuxrun" in err
 
@@ -92,7 +97,7 @@ def test_command_line_errors(argv, capsys, monkeypatch):
     exitcode = main()
     assert exitcode == 1
     stdout, stderr = capsys.readouterr()
-    assert "usage: tuxrun" in stdout
+    assert "usage: tuxrun" in stderr
     assert "tuxrun: error:" in stderr
 
 
@@ -129,3 +134,55 @@ def test_ignores_empty_line_from_lava_run_logfile(tuxrun_args, lava_run, tmp_pat
     logdata = yaml.safe_load(log.open())
     assert type(logdata[0]) is dict
     assert type(logdata[1]) is dict
+
+
+def test_tuxmake_directory(monkeypatch, tmp_path, run):
+    tuxmake_build = tmp_path / "build"
+    tuxmake_build.mkdir()
+    (tuxmake_build / "metadata.json").write_text(
+        """
+        {
+            "results": {
+                "artifacts": {"kernel": ["bzImage"], "modules": ["modules.tar.xz"]}
+            },
+            "build": {"target_arch": "x86_64"}
+        }
+        """
+    )
+    monkeypatch.setattr("sys.argv", ["tuxrun", "--tuxmake", str(tuxmake_build)])
+
+    main()
+    run.assert_called()
+    options = run.call_args[0][0]
+    assert options.kernel == f"file://{tuxmake_build}/bzImage"
+    assert options.device == "qemu-x86_64"
+
+
+def test_no_modules(monkeypatch, tmp_path, run):
+    tuxmake_build = tmp_path / "build"
+    tuxmake_build.mkdir()
+    (tuxmake_build / "metadata.json").write_text(
+        """
+        {
+            "results": {
+                "artifacts": {"kernel": ["bzImage"]}
+            },
+            "build": {"target_arch": "x86_64"}
+        }
+        """
+    )
+    monkeypatch.setattr("sys.argv", ["tuxrun", "--tuxmake", str(tuxmake_build)])
+
+    main()
+    run.assert_called()
+    options = run.call_args[0][0]
+    assert options.modules is None
+
+
+def test_invalid_tuxmake_directory(monkeypatch, tmp_path, capsys):
+    monkeypatch.setattr("sys.argv", ["tuxrun", "--tuxmake", str(tmp_path)])
+    with pytest.raises(SystemExit) as exit:
+        main()
+        assert exit.status_code != 0
+    _, err = capsys.readouterr()
+    assert "metadata.json" in err
